# Project Title

A simple but powerful module that will provide you many useful methods.<br/>



## **Getting Started** <h3>
This module can provide you with powerful functions such as email(...), color_text(...),
take_src(...), convert_currency(...), compress(...), and many more functions, which otherwise,
you would be writing on your own, wasting time as that code had already been
written and is just an **_import_** statement away...

**tj module helps implement
DRY** _(**D**on't **R**epeat **Y**ourself)_
**and KISS** _(**K**eep **I**t **S**imple **S**tupid)_<br/>


### **Prerequisites**<h3>
These are some of the modules required by tj module-

* *cryptography*
* *autopy*
* *colorama*
* *pyAesCrypt*
* *forex-python*
* *tqdm*
<br/>


### **Installing**<h2>
You can install tj module by using pip.

```
pip install tj
```
And the latest version of the tj module will be installed.
To check if it is installed correctly, try
```
>>>import tj
>>>tj.__version__
'2.8.6'
>>>
```
<br/>


## **Exernal modules used**<h3>
* *[cryptograhy](https://pypi.org/project/cryptography/)* - Used for encryption and decryption methods
* *[pyAesCrypt](https://pypi.org/project/pyAesCrypt/)* - Used for file encryption and decryption
* *[colorama](https://pypi.org/project/colorama/)* - Used to enable terminal colors
* *[autopy](https://pypi.org/project/autopy/)* - Used to capture screenshots
* *[forex-python](https://pypi.org/project/forex-python/)* - Used to fetch currency exchange rates
* *[tqdm](https://pypi.org/project/tqdm/)* - Used for progress bar and progress information support
<br/>

## **Versions**<h3>
You can view **[Versions.md](Versions.md)** to see the version history of this project
in a glimpse.<br/>


## **Contributing**<h3>
Please feel free to contribute and give ideas for this project. You can add any
functions, modules, methods, which you think, can save time or if they provide
solution to a difficult problem.<br/>


## **License**<h4>
This project is licensed under the *MIT License* - see the **[LICENSE.md](LICENSE.md)** file for details<br/>


## **What's new in this version**<h3>
**Last Major Release**: 2.8.0 updated on 11:35 PM 3rd March 2019

* Updated some docuentation
* Introduced instant_input(...) function
<br/>

**This version**: 2.8.6 updated on 11:10 PM 5th March 2019

* Updated some docuentation
* Introduced instant_input(...) function
* Fixed bugs
* Fixed bugs in delete(...) function
* Fixed minor bugs
* Fixed bugs and added get_ip_address(...) function


## **Authors**<h3>

* **Tushar Jain** - *Repository Maintainer* - [tusharlock10](https://github.com/tusharlock10)